@@ -3,7 +3,7 @@ from typing import Callable
 from loguru import logger
 
 from deciphon_api.core.settings import Settings
-from deciphon_api.sched import sched_cleanup, sched_init
+from deciphon_api.sched.sched import sched_cleanup, sched_init
 
 __all__ = ["create_start_handler", "create_stop_handler"]
 
